@@ -170,6 +170,8 @@ class PhysicalQuantity:
         else:
             return self.__class__(value, unit)
 
+    __truediv__ = __div__
+
     def __rdiv__(self, other):
         if not isPhysicalQuantity(other):
             return self.__class__(other/self.value, pow(self.unit, -1))
@@ -398,6 +400,8 @@ class PhysicalUnit:
             return PhysicalUnit(self.names+{str(other): -1},
                                 self.factor/other, self.powers)
 
+    __truediv__ = __div__
+
     def __rdiv__(self, other):
         if self.offset != 0 or (isPhysicalUnit (other) and other.offset != 0):
             raise TypeError("cannot divide units with non-zero offset")
@@ -621,11 +625,11 @@ _help = []
 
 def _addUnit(name, unit, comment=''):
     if _unit_table.has_key(name):
-	raise KeyError, 'Unit ' + name + ' already defined'
+        raise KeyError, 'Unit ' + name + ' already defined'
     if comment:
         _help.append((name, comment, unit))
     if type(unit) == type(''):
-	unit = eval(unit, _unit_table)
+        unit = eval(unit, _unit_table)
         for cruft in ['__builtins__', '__args__']:
             try: del _unit_table[cruft]
             except: pass
@@ -636,8 +640,8 @@ def _addPrefixed(unit):
     _help.append('Prefixed units for %s:' % unit)
     _prefixed_names = []
     for prefix in _prefixes:
-	name = prefix[0] + unit
-	_addUnit(name, prefix[1]*_unit_table[unit])
+        name = prefix[0] + unit
+        _addUnit(name, prefix[1]*_unit_table[unit])
         _prefixed_names.append(name)
     _help.append(', '.join(_prefixed_names))
 
@@ -716,7 +720,7 @@ _help.append('Area units:')
 
 _addUnit('ha', '10000*m**2', 'hectare')
 _addUnit('acres', 'mi**2/640', 'acre')
-_addUnit('b', '1.e-28*m', 'barn')
+_addUnit('b', '1.e-28*m**2', 'barn')
 
 # Volume units
 _help.append('Volume units:')
