@@ -1,7 +1,7 @@
 # Package Scientific.TkWidgets
 
 """
-@undocumented: Utility*
+@undocumented: Utility
 """
 
 from Utility import FilenameEntry, FloatEntry, IntEntry, ButtonBar, StatusBar
